@@ -119,14 +119,17 @@ window.addEventListener('load', function () {
   }, true)
 })
 
-require('util/settings/settings.js').initialize()
+require('dbMigration.js')
+
 require('menuBarVisibility.js').initialize()
 require('navbar/tabActivity.js').init()
 require('navbar/tabColor.js').initialize()
 require('navbar/goBackButton.js').initialize()
-require('places/places.js').initialize()
 require('downloadManager.js').initialize()
 require('webviewMenu.js').initialize()
+require('menuRenderer.js').initialize()
+require('keybindings.js').initialize()
+require('pdfViewer.js').initialize()
 
 // default searchbar plugins
 
