@@ -7,6 +7,8 @@ var focusMode = require('focusMode.js')
 var searchbar = require('searchbar/searchbar.js')
 var searchbarPlugins = require('searchbar/searchbarPlugins.js')
 var places = require('places/places.js')
+var urlParser = require('util/urlParser.js')
+var {db} = require('util/database.js')
 const formatRelativeDate = require('util/relativeDate.js')
 
 bangsPlugin.registerCustomBang({
@@ -145,7 +147,7 @@ bangsPlugin.registerCustomBang({
     var newTask = getTaskByNameOrNumber(text)
 
     if (newTask) {
-      newTask.tabs.add(currentTab)
+      newTask.tabs.add(currentTab, {atEnd: true})
     } else {
       // create a new task with the given name
       var newTask = tasks.get(tasks.add(undefined, tasks.getIndex(tasks.getSelected().id) + 1))
@@ -293,3 +295,46 @@ bangsPlugin.registerCustomBang({
     }, {limit: Infinity})
   }
 })
+
+bangsPlugin.registerCustomBang({
+  phrase: '!exportbookmarks',
+  snippet: l('exportBookmarks'),
+  isAction: true,
+  fn: function () {
+    // build the tree structure
+    var root = document.createElement('body')
+    var heading = document.createElement('h1')
+    heading.textContent = 'Bookmarks'
+    root.appendChild(heading)
+    var innerRoot = document.createElement('dl')
+    root.appendChild(innerRoot)
+
+    var folderRoot = document.createElement('dt')
+    innerRoot.appendChild(folderRoot)
+    var folderHeading = document.createElement('h3')
+    folderHeading.textContent = 'Min Bookmarks'
+    folderRoot.appendChild(folderHeading)
+    var folderBookmarksList = document.createElement('dl')
+    folderRoot.appendChild(folderBookmarksList)
+
+    db.places.each(function (item) {
+      if (item.isBookmarked) {
+        var itemRoot = document.createElement('dt')
+        var a = document.createElement('a')
+        itemRoot.appendChild(a)
+        folderBookmarksList.appendChild(itemRoot)
+
+        a.href = urlParser.getSourceURL(item.url)
+        a.setAttribute('add_date', Math.round(item.lastVisit / 1000))
+        a.textContent = item.title
+        // Chrome will only parse the file if it contains newlines after each bookmark
+        var textSpan = document.createTextNode('\n')
+        folderBookmarksList.appendChild(textSpan)
+      }
+    }).then(function () {
+      // save the result
+      var savePath = electron.remote.dialog.showSaveDialogSync({defaultPath: 'bookmarks.html'})
+      require('fs').writeFileSync(savePath, root.outerHTML)
+    })
+  }
+})
